---
title: 'application:application'
url: 'https://docs.danami.com/juggernaut/command-line-interface/application/application-application'
markdown: 'https://docs.danami.com/juggernaut/command-line-interface/application/application-application.md'
date: '2026-10-07'
description: 'Configure the panel application settings. juggernaut --task=application:application Option Value Default Description --environment <production|development> production The mode of the application. --ui_theme <string> The theme to use for the extension. Themes: obsidian --lo…'
taxonomy:
  category:
    - docs
---

[](#)  [ Basics ](https://docs.danami.com/juggernaut/)     [ Command Line Interface ](https://docs.danami.com/juggernaut/command-line-interface)      Application       application:application    

# application:application

Configure the panel application settings.

```
juggernaut --task=application:application
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--environment` | <production\|development> | production | The mode of the application. |
| `--ui_theme` | <string> |  | The theme to use for the extension. Themes: obsidian |
| `--locale` | <string> |  | The default locale of the application. Locales: en-us, ca-es, cs-cz, da-dk, de-de, el-gr, es-es, fi-fi, fr-fr, hu-hu, id-id, it-it, ja-jp, ko-kr, ms-my, nb-no, nl-nl, pl-pl, pt-br, pt-pt, ro-ro, ru-ru, sv-se, th-th, tl-ph, tr-tr, uk-ua, vi-vn, zh-chs, zh-cht |
| `--grid_rows` | <10\|25\|50\|100\|500\|1000> | 25 | The default number of rows shown when viewing a grid. |
| `--file_dataset_limit` | <5000\|10000\|20000\|40000\|60000\|80000> | 5000 | The default data limit for file based data sets. |
| `--time_format` | <12\|24> | 24 | The time format to use when displaying log information. |
| `--no_frames_action` | <redirect\|show\_notice\|do\_nothing> | redirect | The action to take when the application is not loaded within its frameset. |
| `--dashboard_refresh` | <0\|30\|90\|180\|240\|480\|600\|900> | 240 | How often to refresh the dashboard (in seconds). |
| `--auto_update_interval` | <disabled\|weekly\|monthly> | weekly | How often to do application updates. |
| `--auto_update_hour` |  |  | The hour of day to do application updates. |
| `--auto_update_day_of_week` |  |  | The day of week to do application updates (weekly interval, 0 = Sunday). |
| `--auto_update_day_of_month` |  |  | The day of the month to do application updates (monthly interval). |
| `--trusted_hosts` | <string1,string2> |  | The trusted hostnames allowed to access the extension. |
| `--trusted_hosts_add` | <string> |  | Add a single entry to trusted\_hosts. |
| `--trusted_hosts_del` | <string> |  | Remove a single entry from trusted\_hosts. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |

## Examples

```
// set the dashboard_refresh
juggernaut --task=application:application --dashboard_refresh=480

// reset the dashboard_refresh back to its default value
juggernaut --task=application:application --default_option=dashboard_refresh

// reset all settings to their default values
juggernaut --task=application:application --default=yes

// do automatic updates every Sunday at 2:00 AM
juggernaut --task=application:application --auto_update_interval=weekly --auto_update_day_of_week=0 --auto_update_hour=2

// set the locale to German with the 12 hour time format
juggernaut --task=application:application --locale=de-de --time_format=12
```

 [ ](https://docs.danami.com/juggernaut/command-line-interface/application/application-about) [](https://docs.danami.com/juggernaut/command-line-interface/application/application-dashboard)

---

## Navigation

- Previous: [application:about](https://docs.danami.com/juggernaut/command-line-interface/application/application-about.md)
- Next: [application:dashboard](https://docs.danami.com/juggernaut/command-line-interface/application/application-dashboard.md)
